=========
CHANGELOG
=========
- 0.7.0
    Add the last 7 enzymes

    Correct block-code in user-guide

- 0.6.1
    Add 7 enzymes

    Correct some typo

- 0.6.0
    Finish docs

    Minor change in user-define enzymes
    
    Alpha to Beta version

- 0.5.4
    Bugfix: protect new enzyme name when a new enzyme is directly inputted

- 0.5.3
    Writing Doc

- 0.5.2
    Incorporating tests, rtfd and Gitlab